@@ -17,6 +17,7 @@ from .nanowires import (
     convert_NWN_to_MNR,
     add_wires,
     add_electrodes,
+    get_edge_indices,
 )
 
 from .line_functions import (
@@ -31,6 +32,8 @@ from .calculations import (
     create_matrix,
     solve_network,
     solve_drain_current,
+    solve_nodal_current,
+    solve_edge_current,
     scale_sol,
 )
 
@@ -49,3 +52,7 @@ from .dynamics import (
 from .units import (
     get_units
 )
+
+from ._models import (
+    set_chen_params,
+)
\ No newline at end of file
